<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
    
    <xsl:variable name="facultyName" select="/system-index-block/calling-page/system-page/title"/>
    
    <xsl:template match="/system-index-block/calling-page/system-page">
        <xsl:apply-templates select="system-data-structure"/>
    </xsl:template>
    
    <xsl:template match="system-data-structure">
        <div class="faculty" role="main">
            <xsl:apply-templates select="EmployeeId"/>
            <xsl:apply-templates select="PositionInfo"/>
            <xsl:apply-templates select="HeadshotFileSmall"/>
            <xsl:apply-templates select="headshot_thumbnail"/>
            <xsl:apply-templates select="Description"/>
            <xsl:apply-templates select="Resume"/>
            <xsl:apply-templates select="PersonName"/>
            <xsl:apply-templates select="ContactMethod"/>
            
            <xsl:apply-templates select="HeadshotFileLarge"/>
            
            <!--
                <div class="disclaimer">
                <p></p>
                </div>
            -->
        </div>
    </xsl:template>
    
    <xsl:template match="PersonName"/>
    
    <xsl:template match="PositionInfo">
        <xsl:choose>
            <xsl:when test="PositionTitle=''"/>
            <xsl:otherwise>
                <div class="position">
                    <strong>
                        <xsl:value-of select="PositionTitle"/>
                    </strong>, <a>
                        <xsl:attribute name="href">
                            <xsl:value-of select="OrganizationalUnitPrimary/path"/>
                        </xsl:attribute>
                        <xsl:value-of select="OrganizationalUnitPrimary/display-name"/>
                    </a>
                </div>
                <xsl:if test="not(OrganizationalUnitsAssociated/AssociatedDepartment/path='/')">
                    <xsl:for-each select="OrganizationalUnitsAssociated/AssociatedDepartment">
                        <div class="position">
                            <strong>Associated Department</strong>: <a>
                                <xsl:attribute name="href">
                                    <xsl:value-of select="path"/>
                                </xsl:attribute>
                                <xsl:value-of select="display-name"/>
                            </a>
                        </div>
                    </xsl:for-each>
                    
                </xsl:if>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    
    <xsl:template match="ContactMethod"/>
    
    <xsl:template match="Resume">
        <xsl:if test="not(InternetWebAddress='')">
            <br/>
            <a>
                <xsl:attribute name="href">
                    <xsl:value-of select="InternetWebAddress"/>
                </xsl:attribute>My Website </a>
            <br/>
        </xsl:if>
        <xsl:apply-templates select="ResumeFile"/>
        <xsl:apply-templates select="EducationHistory"/>
        <xsl:apply-templates select="InterestsandSpecialties"/>
        <xsl:apply-templates select="Achievements"/>
        <xsl:apply-templates select="Associations"/>
        <xsl:apply-templates select="PublicationHistory"/>
    </xsl:template>
    
    <xsl:template match="ResumeFile">
        <xsl:if test="not(path='/')">
            <br/>
            <a>
                <xsl:attribute name="href">
                    <xsl:value-of select="path"/>
                </xsl:attribute>My Curriculum Vitae </a>
            <br/>
        </xsl:if>
    </xsl:template>
    
    <xsl:template match="EducationHistory">
        <xsl:choose>
            <xsl:when test="(SchoolOrInstitution/DegreeDate &lt; 1901) or (SchoolOrInstitution/DegreeDate='') or (SchoolOrInstitution/InstitutionName='') or (SchoolOrInstitution/DegreeName='')"/>
            <xsl:otherwise>
                <h4>Education</h4>
                <ul class="educationHistory">
                    <xsl:for-each select="SchoolOrInstitution">
                        
                        <xsl:choose>
                            <xsl:when test="DegreeDate &lt; 1901"/>
                            <xsl:when test="DegreeDate=''"/>
                            <xsl:when test="InstitutionName=''"/>
                            <xsl:when test="DegreeName=''"/>
                            <xsl:when test="DegreeName='Other'">
                                <li>
                                    <xsl:value-of select="DegreeTextName"/>, <xsl:value-of select="InstitutionName"/>, <xsl:value-of select="DegreeDate"/>. </li>
                                
                            </xsl:when>
                            <xsl:otherwise>
                                <li>
                                    <xsl:value-of select="DegreeName"/>, <xsl:value-of select="InstitutionName"/>, <xsl:value-of select="DegreeDate"/>. </li>
                            </xsl:otherwise>
                        </xsl:choose>
                    </xsl:for-each>
                    
                </ul>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    
    <xsl:template match="InterestsandSpecialties">
        <xsl:choose>
            <xsl:when test="(Interests/InterestFreeText[position()=1]='')"/>
            <xsl:otherwise>
                <h4>Interests</h4>
                <ul>
                    <xsl:for-each select="Interests/InterestFreeText">
                        <xsl:if test="node()">
                            <li class="interest">
                                <xsl:value-of select="node()"/>
                            </li>
                        </xsl:if>
                    </xsl:for-each>
                </ul>
            </xsl:otherwise>
            
        </xsl:choose>
    </xsl:template>
    
    <xsl:template match="Achievements">
        <xsl:if test="description/node()">
            <h4>Achievements</h4>
            <div class="achievements">
                <xsl:copy-of select="description/node()"/>
            </div>
        </xsl:if>
    </xsl:template>
    
    <xsl:template match="Associations">
        <xsl:if test="description/node()">
            <h4>Associations</h4>
            <div class="associations">
                <xsl:copy-of select="description/node()"/>
            </div>
        </xsl:if>
    </xsl:template>
    
    <xsl:template match="PublicationHistory">
        <xsl:if test="description/node()">
            <h4>Publications &amp; Presentations</h4>
            <div class="publications">
                <xsl:copy-of select="description/node()"/>
            </div>
        </xsl:if>
    </xsl:template>
    
    <xsl:template match="Description">
        <xsl:if test="node()">
            <div class="description">
                <xsl:copy-of select="node()"/>
            </div>
        </xsl:if>
    </xsl:template>
    
    <xsl:template match="headshot_thumbnail"/>
    
    <xsl:template match="HeadshotFileSmall">
        <xsl:if test="not(path='/')">
            <img alt="headshot" title="headshot">
                <xsl:attribute name="src">
                    <xsl:value-of select="path"/>
                </xsl:attribute>
                <xsl:attribute name="align">left</xsl:attribute>
                <xsl:attribute name="hspace">15</xsl:attribute>
                <xsl:attribute name="vspace">15</xsl:attribute>
            </img>
        </xsl:if>
    </xsl:template>
    
    <xsl:template match="EmployeeId">
        <div id="toc"> Please <a><xsl:attribute name="href">
            http://directory.service.emory.edu/?eodentry=<xsl:value-of select="."/>
        </xsl:attribute>click here for this faculty member's CONTACT INFORMATION</a>,
            including phone number(s), e-mail address, and office locations. <em>(Please note that
                detailed contact information is not available for all faculty members, especially
                when accessed from off-campus locations.)</em>
        </div>
    </xsl:template>
    
    <xsl:template match="OrganizationalUnitPrimary"/>
    
    <xsl:template match="OrganizationalUnitAssociated"/>
    
    <xsl:template match="HeadshotFileLarge"/>
    
    <xsl:template match="system-page/system-data-structure"/>
    
</xsl:stylesheet>